@@ -12,6 +12,18 @@ G_BEGIN_DECLS
 GType gweather_location_level_get_type (void) G_GNUC_CONST;
 #define GWEATHER_TYPE_LOCATION_LEVEL (gweather_location_level_get_type ())
 
+/* enumerations from "gweather-weather.h" */
+GType gweather_provider_get_type (void) G_GNUC_CONST;
+#define GWEATHER_TYPE_PROVIDER (gweather_provider_get_type ())
+GType gweather_wind_direction_get_type (void) G_GNUC_CONST;
+#define GWEATHER_TYPE_WIND_DIRECTION (gweather_wind_direction_get_type ())
+GType gweather_sky_get_type (void) G_GNUC_CONST;
+#define GWEATHER_TYPE_SKY (gweather_sky_get_type ())
+GType gweather_phenomenon_get_type (void) G_GNUC_CONST;
+#define GWEATHER_TYPE_PHENOMENON (gweather_phenomenon_get_type ())
+GType gweather_qualifier_get_type (void) G_GNUC_CONST;
+#define GWEATHER_TYPE_QUALIFIER (gweather_qualifier_get_type ())
+
 /* enumerations from "gweather-enums.h" */
 GType gweather_forecast_type_get_type (void) G_GNUC_CONST;
 #define GWEATHER_TYPE_FORECAST_TYPE (gweather_forecast_type_get_type ())
